<?php

namespace Realestate\Neighbourhood\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Realestate\Neighbourhood\Http\Resources\NeighbourhoodResource;
use Realestate\Neighbourhood\Http\Resources\NeighbourhoodsCollection;
use Realestate\Neighbourhood\Scopes\SectionsPublicScope;
use Realestate\Neighbourhood\Models\Sections;

class SectionsPublicController extends BaseController
{

    /**
     * Show sections's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Sections::pushScope(new RequestScope())
            ->pushScope(new SectionsPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $sections = new SectionsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('neighbourhood::sections.names'))
            ->view('neighbourhood::public.sections.index')
            ->data(compact('sections', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show sections.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Sections::findBySlug($slug);
        $data = new SectionsResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('neighbourhood::sections.name'))
            ->view('neighbourhood::public.sections.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
