<?php

namespace Realestate\Neighbourhood\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Realestate\Neighbourhood\Events\SectionsAction as SectionsActionEvent;
use Realestate\Neighbourhood\Notifications\SectionsAction as SectionsActionNotification;
use Litepie\Actions\Concerns\AsAction;

class SectionsAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the SectionsActionEvent.
     *
     * @param   SectionsActionEvent  $event
     * @return mixed
     */
    public function handle(SectionsActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $sections.
     *
     * @param   SectionsActionEvent  $event
     * @return void
     */
    public function create(SectionsActionEvent $event)
    {
        $client = $event->sections->client;
        Notification::send($client, new SectionsActionNotification($event));
    }

    /**
     * Handle the SectionsActionEvent as a listener.
     *
     * @param   SectionsActionEvent  $event
     * @return mixed
     */
    public function asListener(SectionsActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   SectionsActionEvent  $event
     * @return bool
     */
    private function isAllowed(SectionsActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
