<?php

namespace Realestate\Neighbourhood\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Realestate\Neighbourhood\Events\SectionsWorkflow as SectionsWorkflowEvent;
use Realestate\Neighbourhood\Notifications\SectionsWorkflow as SectionsWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class SectionsWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(SectionsWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $sections is submitted.
     *
     * @param SectionsWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(SectionsWorkflowEvent $event)
    {
        $client = $event->sections->client;
        Notification::send($client, new SectionsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $sections is published.
     *
     * @param SectionsWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(SectionsWorkflowEvent $event)
    {
        $client = $event->sections->client;
        Notification::send($client, new SectionsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $sections is approved.
     *
     * @param SectionsWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(SectionsWorkflowEvent $event)
    {
        $client = $event->sections->client;
        Notification::send($client, new SectionsWorkflowNotification($event));
    }

    /**
     * Handles the $sections workflow event as a listener.
     *
     * @param SectionsWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(SectionsWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
