<?php

namespace Realestate\Neighbourhood\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Realestate\Neighbourhood\Models\Neighbourhood;

class NeighbourhoodPolicy
{


    /**
     * Determine if the given user can view the neighbourhood.
     *
     * @param Authenticatable $user
     * @param Neighbourhood $neighbourhood
     *
     * @return bool
     */
    public function view(Authenticatable $user, Neighbourhood $neighbourhood)
    {
        if ($authUser->canDo('neighbourhood.neighbourhood.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $neighbourhood->is_owner;
    }

    /**
     * Determine if the given user can create a neighbourhood.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('neighbourhood.neighbourhood.create');
    }

    /**
     * Determine if the given user can update the given neighbourhood.
     *
     * @param Authenticatable $user
     * @param Neighbourhood $neighbourhood
     *
     * @return bool
     */
    public function update(Authenticatable $user, Neighbourhood $neighbourhood)
    {
        if ($user->canDo('neighbourhood.neighbourhood.edit') && $user->isAdmin()) {
            return true;
        }

        return $neighbourhood->is_owner;
    }

    /**
     * Determine if the given user can delete the given neighbourhood.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Neighbourhood $neighbourhood)
    {
        return $neighbourhood->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
