<?php

namespace Realestate\Neighbourhood\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Realestate\Neighbourhood\Models\Sections;

class SectionsPolicy
{


    /**
     * Determine if the given user can view the sections.
     *
     * @param Authenticatable $user
     * @param Sections $sections
     *
     * @return bool
     */
    public function view(Authenticatable $user, Sections $sections)
    {
        if ($authUser->canDo('neighbourhood.sections.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $sections->is_owner;
    }

    /**
     * Determine if the given user can create a sections.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('neighbourhood.sections.create');
    }

    /**
     * Determine if the given user can update the given sections.
     *
     * @param Authenticatable $user
     * @param Sections $sections
     *
     * @return bool
     */
    public function update(Authenticatable $user, Sections $sections)
    {
        if ($user->canDo('neighbourhood.sections.edit') && $user->isAdmin()) {
            return true;
        }

        return $sections->is_owner;
    }

    /**
     * Determine if the given user can delete the given sections.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Sections $sections)
    {
        return $sections->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
